@@ -16,17 +16,21 @@ class Loader(threading.Thread):
 				self.stop(success=False)
 	def run(self):
 		self.running = True
+		self.released = True
 		while self.running:
-			for i in ["|", "/", "-", "\\"]:
-				if self.message != self.last_message:
-					print(self.__empty_message__(length=len(f"{self.message} ...   ")), end="\r")
-					self.message = self.__clean_message__(self.message)
-				print(f"{self.message} ... {i}", end="\r")
-				self.last_message = self.message
-				if not self.running: break
-				time.sleep(0.33)
+			if not self.released:
+				time.sleep(1)
+			else:
+				for i in ["|", "/", "-", "\\"]:
+					if self.message != self.last_message:
+						print(self.__empty_message__(length=len(f"{self.message} ...   ")), end="\r")
+						self.message = self.__clean_message__(self.message)
+					print(f"{self.message} ... {i}", end="\r")
+					self.last_message = self.message
+					if not self.running: break
+					time.sleep(0.33)
 		self.running = "stopped"
-	def stop(self, message=None, success=True, response=None):
+	def stop(self, message=None, success=True, response=None, quiet=False):
 		if response == None:
 			if message == None: message = self.message
 		else:
@@ -40,11 +44,12 @@ class Loader(threading.Thread):
 			if self.running == "stopped": break
 			time.sleep(0.5)
 		if self.running != "stopped": raise ValueError(f"Unable to stop loader [{self.message}].")
-		print(self.__empty_message__(length=len(f"{self.last_message} ...   ")), end="\r")
-		if success:
-			print(f"{message} ... done")
-		else:
-			print(f"{message} ... {color.red}failed{color.end}")
+		if not quiet:
+			print(self.__empty_message__(length=len(f"{self.last_message} ...   ")), end="\r")
+			if success:
+				print(f"{message} ... done")
+			else:
+				print(f"{message} ... {color.red}failed{color.end}")
 	def mark(self, old_message=None, new_message=None, success=True, response=None):
 		if response != None:
 			if response["error"] == None:
@@ -58,6 +63,10 @@ class Loader(threading.Thread):
 		else:
 			print(f"{old_message} ... {color.red}failed{color.end}")
 		if new_message != None: self.message = new_message
+	def hold(self):
+		self.released = False
+	def release(self):
+		self.released = True
 	# system functions.
 	def __clean_message__(self, message):
 		if message[-len(" ..."):] == " ...": message = message[:-4]
